Method: GitGo::Connection::Base#rm

Defined in:
lib/git_go/connection/base.rb

#rm(path) ⇒ Hash

Removes a file or directory at the provided path. It will take the path relative from #current_path if no absolute path was provided.

Parameters:

  • path (String)

    the path to the file or directory to remove.

Returns:

  • (Hash)

    containing #bash response data.



64
65
66
# File 'lib/git_go/connection/base.rb', line 64

def rm(path)
  bash("rm -rf '#{path}'")
end